Page({
  data: {
    isLogin: false,  // 登录状态
    validUsers: {    // 存储用户名、密码和头像信息
      username: '',
      password: '',
      avatarUrl: ''
    },
    isHidden: true,  // 登录弹窗状态
  },

  // 页面加载时获取缓存的用户信息
  onLoad() {
    this.loadUserInfo();  // 调用加载用户信息的方法
  },

  // 页面显示时确保用户信息刷新
  onShow() {
    this.loadUserInfo();  // 每次进入页面时刷新用户信息
    if (typeof this.getTabBar === 'function' && this.getTabBar()) {
      this.getTabBar().setData({});
    }
    // 隐藏返回首页按钮
    if (wx.canIUse('hideHomeButton')) {
      wx.hideHomeButton();
    }
  },

  // 加载用户信息并更新页面
  loadUserInfo() {
    const storedUserInfo = wx.getStorageSync('userInfo');  // 获取缓存中的用户信息
    if (storedUserInfo && storedUserInfo.username && storedUserInfo.password) {
      // 如果缓存中有用户名和密码，更新页面上的数据
      this.setData({
        validUsers: storedUserInfo,  // 更新用户信息
        isLogin: true,  // 设置登录状态为 true
      });
    }
  },

  // 获取用户的用户名
  getUsername(e) {
    const username = e.detail.value;
    this.setData({
      'validUsers.username': username
    });

    // 保存用户名到缓存
    let userInfo = wx.getStorageSync('userInfo') || {};
    userInfo.username = username;
    wx.setStorageSync('userInfo', userInfo);
  },

  // 获取用户的密码
  getPassword(e) {
    const password = e.detail.value;
    this.setData({
      'validUsers.password': password
    });

    // 保存密码到缓存
    let userInfo = wx.getStorageSync('userInfo') || {};
    userInfo.password = password;
    wx.setStorageSync('userInfo', userInfo);
  },

  // 显示登录弹窗
  goLogin() {
    this.setData({
      isHidden: false
    });
  },

  // 取消登录弹窗
  potNo() {
    this.setData({
      isHidden: true
    });
  },

  // 编辑个人资料
  EditProfile() {
    wx.navigateTo({
      url: '/shoping/EditProfile/EditProfile'
    });
  },

  // 确认登录弹窗
  popYes() {
    const { username, password } = this.data.validUsers;
    if (!username || !password) {
      wx.showToast({
        icon: 'error',
        title: '请填写用户名和密码',
      });
      return;
    }

    // 保存用户名和密码到缓存
    wx.setStorageSync('userInfo', this.data.validUsers);
    this.setData({
      isLogin: true,  // 设置登录状态为 true
      isHidden: true, // 隐藏弹窗
    });
  },

  // 跳转到阈值页面
  goToThreshold() {
    wx.navigateTo({
      url: '/pages/threshold/threshold'
    });
  },

  // 点击退出登录
  tuichu() {
    // 清除缓存
    wx.clearStorageSync();

    // 重置登录状态
    this.setData({
      isLogin: false,
      validUsers: {}  // 清空用户信息
    });

    // 跳转到登录页面
    wx.reLaunch({
      url: '/shoping/Home/Home' // 登录页面的路径
    });
  }
});
